# 9. Embedded programming

This week I worked on defining my final project idea and started to getting used to the documentation process.

## Board 

This week I decided to redesign my board using the Seeed ESP32C3 shall. 

Following Prof. Gershenfeld comments about pull up vs. pull down resistors I educated myself and now can simplify 
my circuit by removing the pull down resistors and use the built in pull up resistors with some code changes you can 
see [here](https://www.seeedstudio.com/blog/2020/02/21/pull-up-resistor-vs-pull-down-differences-arduino-guide/)

![Board Design](../images/imagW8/Design1.png)

I used the SEEED and Fab libraries. I am still not sure what connectors to use for the button and motor/pump and so 
I just used the connectors in the Fab library. 

I pulled up the ESP32ESP pinout map 

![Board Design](../images/imagW8/Design2.png)

then got to updating the schematic  

![Board Design](../images/imagW8/Design3.png)

I moved to placing down the components 

![Board Design](../images/imagW8/Design4.jpg)

And next was routing 

![Board Design](../images/imagW8/Design5.jpg)

I finaly decided to shrink the foot print down a bit 

![Board Design](../images/imagW8/Design6.jpg)

And now we can move to making the board 

### Bantam milling 

I used the Bantam mill and it was very straight forward. 

First in Fusion, I went to the manufacturing menue and experoted the files  

![](../images/imagW8/B1.jpg)

In Bantam I loaded the copper top and profile files 

![](../images/imagW8/B2.jpg)

I used double sided tape and put the board in place 

![](../images/imagW8/B4.jpg)

The machine made sure I loaded the right tips:

![](../images/imagW8/B3.jpg)

It ran through the cut 

![](../images/imagW8/B5.jpg)

I cut 2 to make sure I had a back up without needed to set everything up again 

![](../images/imagW8/B6.jpg)

I cleaned the board with soap and water

![](../images/imagW8/B7.jpg)


## Assembly 

I only had 3 components to solder the ESP32C3, a resistor and LED as well as connectors for the buttons 






## Coding 

Here I wanted to try out Chat GPT 4.0 and so I asked him for simple blink code and he suggested 

```c
// Pin number for the LED (use the GPIO number, not the board's pin number)
const int ledPin = 7;

// Time interval for the LED to be on and off (in milliseconds)
const unsigned long interval = 1000;
unsigned long previousMillis = 0;

void setup() {
  // Set the LED pin as an output
  pinMode(ledPin, OUTPUT);
}

void loop() {
  // Get the current time
  unsigned long currentMillis = millis();

  // Check if the interval has passed
  if (currentMillis - previousMillis >= interval) {
    // Save the last time the LED state was toggled
    previousMillis = currentMillis;

    // Toggle the LED state
    digitalWrite(ledPin, !digitalRead(ledPin));
  }
}
```

I loaded it and we had a blinking light 

Next I asked Chat GPT to add a button that when pressed would trigger the LED to blink 5 times

Here is the suggested code 

```C

const int ledPin = 7;
const int buttonPin = 2; // Change this to the GPIO number where the button is connected
const unsigned long interval = 1000;
unsigned long previousMillis = 0;
int flashCount = 0;
bool buttonPressed = false;

void setup() {
  pinMode(ledPin, OUTPUT);
  pinMode(buttonPin, INPUT_PULLUP); // Enable the internal pull-up resistor for the button
}

void loop() {
  unsigned long currentMillis = millis();

  if (digitalRead(buttonPin) == LOW) { // Check if the button is pressed
    buttonPressed = true;
  }

  if (buttonPressed && flashCount < 5) {
    if (currentMillis - previousMillis >= interval) {
      previousMillis = currentMillis;
      digitalWrite(ledPin, !digitalRead(ledPin));

      // Turn off the LED after it has been flashed an odd number of times
      if (digitalRead(ledPin) == LOW) {
        flashCount++;
      }
    }
  } else if (flashCount >= 5) {
    flashCount = 0;
    buttonPressed = false;
  }
}

```

We have success!!!



## Milling in Fusion / Genmitsu 3020-Pro-Max

While I believe this is what we needed to get done for this week I also wanted to try and 
I also wanted to try and mill the board by setting up the tool path in fusion and running a small CNC mill 
I have at home the Genmitsu 3020-Pro-Max 

## Board milling set up in Fusion 

I spend time watching a number of tutorials [here](https://www.youtube.com/watch?v=V96JZ8JOm9Y) and [here](https://www.youtube.com/watch?v=kTAC7aWL024)

Set up was largley the same but they took different approach to the tool path choices. 

Here is what I tried 

First I exported the board to 3D board but made sure to uncheck the soldermask option as that will make selecting the copper
traces for milling easier 

![Board milling](../images/imagW8/Design7.jpg)

I kept the board the 1-copper layers visible which is what I want to mill

![Board milling](../images/imagW8/Design71.jpg)

Next I moved the manufacturing workspace 

![Board milling](../images/imagW8/Design72.jpg)

I started a new set up and selected the board as the model 

![Board milling](../images/imagW8/Design74.jpg)

I change the top off set to 0 

![Board milling](../images/imagW8/Design76.jpg)

## Tool path set up 

I started by the 3D adaptive clearing tool path 

![Board milling](../images/imagW8/Design8.jpg)

I choose a 1/8 end mill with aluminum roughing which is what they used in the tutorial 
(this will turn out to be a mistake for my board)

![Board milling](../images/imagW8/Design81.jpg)

Next I set the bounding box to the shape of the board and change Tool containment to 
"tool inside"

![Board milling](../images/imagW8/Design82.jpg)

 
![Board milling](../images/imagW8/Design84.jpg)

Then in the Model section I choose the copper traces

![Board milling](../images/imagW8/Design85.jpg)

Next I selected the board surface as the Bottom height

![Board milling](../images/imagW8/Design86.jpg)

Unchecked the "stock to leave" option 

![Board milling](../images/imagW8/Design87.jpg)

what we can see here is that the tool was not cutting detailed enough. 

![Board milling](../images/imagW8/Design9.jpg)

So I went and reviewed the turtorial and some more google searches and decided to make some changes:

I changed the tool to a smaller one 

![Board milling](../images/imagW8/Design91.jpg)

and change the ramp type to plunge 

![Board milling](../images/imagW8/Design92.jpg)

It looks much better 

![Board milling](../images/imagW8/Design94.jpg)

Now to add the cut option 